@@ -8,6 +8,7 @@ from datetime import datetime
 from json import dumps
 from time import time
 from typing import Any, Dict, List, Optional, Tuple, Union
+from html import unescape
 
 import aiohttp
 
@@ -38,6 +39,7 @@ def strnorm(strin: str) -> List[str]:
             _pre += chr(0x0020)
     return _pre.upper().split()
 
+
 def getcookieval(httpsession: aiohttp.ClientSession, cname: str) -> Optional[str]:
     """
     Extract required cookie from aiohttp.CookieJar instance from aiohttp session.
@@ -67,7 +69,7 @@ def gettag(htmltag: str) -> str:
             _c = htmltag[(_beg + 1):_end]
     if _c != htmltag:
         return chr(0x0020).join(strnorm(_c))
-    return htmltag
+    return unescape(htmltag)
 
 
 async def fagetrefs(fadomain: str,
@@ -99,7 +101,7 @@ async def fagetrefs(fadomain: str,
     _user_ref = dict()
     for _i in _users_json["data"]:
         # Normalise the user name with strnorm() and join resulting list with spaces
-        _user_ref[chr(0x0020).join(strnorm(_i["contact.name"]))] = _i["id"]
+        _user_ref[chr(0x0020).join(strnorm(unescape(_i["contact.name"])))] = _i["id"]
     _debug_log += f"User reference built:\n{dumps(_user_ref, indent=3, ensure_ascii=False)}" + "\n"
     # Get all sites
     r = await httpsession.post(f"https://{fadomain}.facilityapps.com/api/1.0/site_manager/site_data",
@@ -115,7 +117,7 @@ async def fagetrefs(fadomain: str,
     _site_ref = dict()
     for _i in _sites_json["data"]:
         # Normalise the site name with strnorm() and join resulting list with spaces
-        _site_ref[chr(0x0020).join(strnorm(_i["name"]))] = _i["id"]
+        _site_ref[chr(0x0020).join(strnorm(unescape(_i["name"])))] = _i["id"]
     _debug_log += f"Sites reference built:\n{dumps(_site_ref, indent=3, ensure_ascii=False)}" + "\n"
     # Get all floors and spaces
     r = await httpsession.post(f"https://{fadomain}.facilityapps.com/api/1.0/floorplan/spaces/list",
@@ -139,7 +141,7 @@ async def fagetrefs(fadomain: str,
             _spaces_ref[gettag(_r["site.name"])] = dict()
             _log_sites += 1
         if gettag(_r["floor.name"]) not in _spaces_ref[gettag(_r["site.name"])].keys():
-            _floors_ref[gettag(_r["site.name"])][gettag(_r["floor.name"])] = _r["floor.id"]
+            _floors_ref[gettag(_r["site.name"])][gettag(_r["floor.name"])] = unescape(_r["floor.id"])
             _spaces_ref[gettag(_r["site.name"])][gettag(_r["floor.name"])] = dict()
             _log_floors += 1
         if gettag(_r["name"]) not in _spaces_ref[gettag(_r["site.name"])][gettag(_r["floor.name"])].keys():
@@ -162,7 +164,7 @@ class FARequests:
         """
         :return: FA mobile app version
         """
-        return "4.0.1"
+        return "4.1.0"
 
     @staticmethod
     def userquery() -> str:
@@ -582,38 +584,37 @@ class FARequests:
                 "username": usr,
                 "password": pwd,
                 "session_id": str(),
-                "version": "4.0.1",
+                "version": FARequests.getappversion(),
                 "mode": "LogIn",
                 "auth_method": "basic"
                 }
 
     @staticmethod
-    def applogbookform(formdata: Union[Dict, List], sid: str) -> Dict[str, Any]:
+    def applogbookform(formdata: Union[Dict, List], siteid: int, sid: str) -> Dict[str, Any]:
         """
         :param formdata: JSON serializable object representing the form data
+        :param siteid: integer site ID for FA API
         :param sid: session_id token got from login
         :return: dict with application/x-www-form-urlencoded fields to use for app API new logbook item submit
         """
-        return {"T":                "FormCheckList_v11",
-                "L":                "ru_RU",
-                "FormData":         dumps(formdata, ensure_ascii=False),
-                "Objectid":         "Т2",
-                "ObjectType":       "1",
-                "Timestamp":        str(int(time())),
-                "session_id":       sid,
+        return {"T": "FormCheckList_v11",
+                "L": "ru_RU",
+                "FormData": dumps(formdata, ensure_ascii=False),
+                "ReferenceId": str(siteid),
+                "ReferenceType": "1",
+                "Timestamp": str(int(time())),
+                "session_id": sid,
                 "AppVersionNumber": FARequests.getappversion(),
-                "TaskData":         "null"
+                "TaskData": "null"
                 }
 
     @staticmethod
-    def appchecklistsform(siteid: int, sid: str) -> Dict[str, Any]:
+    def appchecklistsform(sid: str) -> Dict[str, Any]:
         """
-        :param siteid: integer site ID for FA API
         :param sid: session_id token got from login
         :return: dict with application/x-www-form-urlencoded fields to use for app API GetChecklists request
         """
-        return {"ObjectNr": str(siteid),
-                "session_id": sid,
+        return {"session_id": sid,
                 "T": "GetChecklists",
                 "L": "ru_RU",
                 "region_code": "ru_RU"
@@ -629,5 +630,6 @@ class FARequests:
         return {"session_id": sid,
                 "T": "getChecklistQuestions_v6",
                 "checkListID": ";".join([str(_i) for _i in formids]),
+                "image_data": "false",
                 "region_code": "ru_RU"
                 }
