@@ -85,6 +85,38 @@ class ImportCellParser:
             return True
         return False
 
+    def _parseintseq(self, cellobject: openpyxl.cell.cell.Cell, allowedvals: List[int]) -> Union[List[str], None]:
+        """
+        Parse value of cell containing string with semicolon separated integers into a list of stringified integers,
+        values in the MS Excel sheet must be given with ; (semicolon) separator
+
+        :param cellobject: openpyxl cell object to parse
+        :param allowedvals: list of allowed integers, if parsed integer not from this list, exception is raised
+        :return: list of stringified integers parsed from the cell
+        """
+        # Trim and split by semicolons
+        _value_raw_list = cellobject.value.strip().split(";")
+        # Trim each item and filter out empty ones, fill filtered list
+        _value_numbers_set = set()
+        for _item in _value_raw_list:
+            _trimmed_item = _item.strip()
+            if _trimmed_item:
+                try:
+                    _trimmed_item_int = int(_trimmed_item)
+                except Exception:
+                    raise ImportCellParserException((f"_parseintseq(): Wrong value in the cell: "
+                                                     f"{_trimmed_item}, values in the list must be integers divided by "
+                                                     f"semicolons"))
+                if _trimmed_item_int in allowedvals:
+                    _value_numbers_set.add(str(_trimmed_item_int))
+                else:
+                    raise ImportCellParserException((f"_parseintseq(): Wrong value in the cell: "
+                                                     f"{_trimmed_item_int}, integer values in the list must belong to "
+                                                     f"{allowedvals}"))
+        _value_numbers_list = list(_value_numbers_set)
+        _value_numbers_list.sort()
+        return _value_numbers_list
+
     def IQF001SITE(self, cellobject: openpyxl.cell.cell.Cell) -> Union[str, None]:
         """
         Parse site name, normalize with strnorm()
@@ -280,7 +312,7 @@ class ImportCellParser:
 
     def IQF011FREQDAYS(self, cellobject: openpyxl.cell.cell.Cell) -> Union[List[str], None]:
         """
-        Parse task recurrence days as list of stringified integers, where ["1", "2", "3", "4", "5", "6", '7']
+        Parse task recurrence days as list of stringified integers, where ["1", "2", "3", "4", "5", "6", "7"]
         corresponds to [Mon, Tue, Wed, Thu, Fri, Sat, Sun], list values in the MS Excel sheet must
         be given with ; (semicolon) separator
 
@@ -291,32 +323,10 @@ class ImportCellParser:
             raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
         if cellobject.value is None:
             return None
-        _value = cellobject.value
-        if not isinstance(_value, str):
+        if not isinstance(cellobject.value, str):
             raise ImportCellParserException((f"IQF011FREQDAYS: Cell contents type is {type(cellobject)}, "
                                              f"string type required"))
-        # Trim and split by semicolons
-        _value_raw_list = _value.strip().split(";")
-        # Trim each item and filter out empty ones, fill filtered list
-        _value_numbers_set = set()
-        for _item in _value_raw_list:
-            _trimmed_item = _item.strip()
-            if _trimmed_item:
-                try:
-                    _trimmed_item_int = int(_trimmed_item)
-                except Exception:
-                    raise ImportCellParserException((f"IQF011FREQDAYS: Wrong value in the cell: "
-                                                     f"{_trimmed_item}, values in the list must be integers divided by "
-                                                     f"semicolons"))
-                if _trimmed_item_int in [1, 2, 3, 4, 5, 6, 7]:
-                    _value_numbers_set.add(str(_trimmed_item_int))
-                else:
-                    raise ImportCellParserException((f"IQF011FREQDAYS: Wrong value in the cell: "
-                                                     f"{_trimmed_item_int}, integer values in the list must be from "
-                                                     f"1 to 7"))
-        _value_numbers_list = list(_value_numbers_set)
-        _value_numbers_list.sort()
-        return _value_numbers_list
+        return self._parseintseq(cellobject, [1, 2, 3, 4, 5, 6, 7])
 
     def IQF012ATMID(self, cellobject: openpyxl.cell.cell.Cell) -> Union[int, None]:
         """
@@ -460,3 +470,39 @@ class ImportCellParser:
         if cellobject.value is None:
             return None
         return str(cellobject.value).strip()
+
+    def IQF021FREQMONTHS(self, cellobject: openpyxl.cell.cell.Cell) -> Union[List[str], None]:
+        """
+        Parse task recurrence months as list of stringified integers, where
+        ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"] corresponds to
+        [Jan, Feb, Mar, Apr, May, Jun, Jul, Aug, Sep, Oct, Nov, Dec], list values in the MS Excel sheet must
+        be given with ; (semicolon) separator
+
+        :param cellobject: openpyxl cell object to parse
+        :return: list of stringified integers parsed from the cell
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        if not isinstance(cellobject.value, str):
+            raise ImportCellParserException((f"IQF021FREQMONTHS: Cell contents type is {type(cellobject)}, "
+                                             f"string type required"))
+        return self._parseintseq(cellobject, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12])
+
+    def IQF022SAMEDAYOFWEEK(self, cellobject: openpyxl.cell.cell.Cell) -> Union[bool, None]:
+        """
+        If monthly recurrence is set, then this parameter defines whether task repeats same day of the week, or same
+        date of each month
+
+        If "yes" then task will repeat same day of the same week as first date of the task, if "no" - then task
+        will repeat same date of the month
+
+        :param cellobject: openpyxl cell object to parse
+        :return: True if cell value is parsed as yes, False otherwise
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        return self._parseyesno(cellobject)
